Flags

Struct Flags 

#[repr(transparent)]
pub struct Flags<T>(pub T);
Flag set wrapping a primitive unsigned integer.

For named, fixed sets of flags use the bitflags crate. Flags<T> is for ad hoc flag manipulation where bit positions are data.

use bitkit::Flags;
const READ: u32 = 1 << 0;
const WRITE: u32 = 1 << 1;
let mut f = Flags::<u32>::empty();
f.enable(READ | WRITE);
assert!(f.has(READ));
assert!(f.has_all(READ | WRITE));

Tuple Fields

0: T

Implementations

Source

impl Flags<u8>

pub const fn empty() -> Self

Empty set.

pub const fn all() -> Self

All bits set.

pub const fn from_bits(b: u8) -> Self

Wrap raw bits.

pub const fn bits(self) -> u8

Underlying bits.

pub const fn has(self, flags: u8) -> bool

Every bit of flags is set in self. (has(0) is true.)

pub const fn has_all(self, flags: u8) -> bool

Alias for has. Reads better at call sites with multiple bits.

pub const fn has_any(self, flags: u8) -> bool

Any bit of flags is set in self.

pub const fn with(self, flags: u8) -> Self

Copy with flags set.

pub const fn without(self, flags: u8) -> Self

Copy with flags cleared.

pub const fn toggled(self, flags: u8) -> Self

Copy with flags toggled.

pub fn enable(&mut self, flags: u8)

Set flags in place.

pub fn disable(&mut self, flags: u8)

Clear flags in place.

pub fn toggle(&mut self, flags: u8)

Toggle flags in place.

Source

impl Flags<u16>

pub const fn empty() -> Self

Empty set.

pub const fn all() -> Self

All bits set.

pub const fn from_bits(b: u16) -> Self

Wrap raw bits.

pub const fn bits(self) -> u16

Underlying bits.

pub const fn has(self, flags: u16) -> bool

Every bit of flags is set in self. (has(0) is true.)

pub const fn has_all(self, flags: u16) -> bool

Alias for has. Reads better at call sites with multiple bits.

pub const fn has_any(self, flags: u16) -> bool

Any bit of flags is set in self.

pub const fn with(self, flags: u16) -> Self

Copy with flags set.

pub const fn without(self, flags: u16) -> Self

Copy with flags cleared.

pub const fn toggled(self, flags: u16) -> Self

Copy with flags toggled.

pub fn enable(&mut self, flags: u16)

Set flags in place.

pub fn disable(&mut self, flags: u16)

Clear flags in place.

pub fn toggle(&mut self, flags: u16)

Toggle flags in place.

Source

impl Flags<u32>

pub const fn empty() -> Self

Empty set.

pub const fn all() -> Self

All bits set.

pub const fn from_bits(b: u32) -> Self

Wrap raw bits.

pub const fn bits(self) -> u32

Underlying bits.

pub const fn has(self, flags: u32) -> bool

Every bit of flags is set in self. (has(0) is true.)

pub const fn has_all(self, flags: u32) -> bool

Alias for has. Reads better at call sites with multiple bits.

pub const fn has_any(self, flags: u32) -> bool

Any bit of flags is set in self.

pub const fn with(self, flags: u32) -> Self

Copy with flags set.

pub const fn without(self, flags: u32) -> Self

Copy with flags cleared.

pub const fn toggled(self, flags: u32) -> Self

Copy with flags toggled.

pub fn enable(&mut self, flags: u32)

Set flags in place.

pub fn disable(&mut self, flags: u32)

Clear flags in place.

pub fn toggle(&mut self, flags: u32)

Toggle flags in place.

Source

impl Flags<u64>

pub const fn empty() -> Self

Empty set.

pub const fn all() -> Self

All bits set.

pub const fn from_bits(b: u64) -> Self

Wrap raw bits.

pub const fn bits(self) -> u64

Underlying bits.

pub const fn has(self, flags: u64) -> bool

Every bit of flags is set in self. (has(0) is true.)

pub const fn has_all(self, flags: u64) -> bool

Alias for has. Reads better at call sites with multiple bits.

pub const fn has_any(self, flags: u64) -> bool

Any bit of flags is set in self.

pub const fn with(self, flags: u64) -> Self

Copy with flags set.

pub const fn without(self, flags: u64) -> Self

Copy with flags cleared.

pub const fn toggled(self, flags: u64) -> Self

Copy with flags toggled.

pub fn enable(&mut self, flags: u64)

Set flags in place.

pub fn disable(&mut self, flags: u64)

Clear flags in place.

pub fn toggle(&mut self, flags: u64)

Toggle flags in place.

Source

impl Flags<u128>

pub const fn empty() -> Self

Empty set.

pub const fn all() -> Self

All bits set.

pub const fn from_bits(b: u128) -> Self

Wrap raw bits.

pub const fn bits(self) -> u128

Underlying bits.

pub const fn has(self, flags: u128) -> bool

Every bit of flags is set in self. (has(0) is true.)

pub const fn has_all(self, flags: u128) -> bool

Alias for has. Reads better at call sites with multiple bits.

pub const fn has_any(self, flags: u128) -> bool

Any bit of flags is set in self.

pub const fn with(self, flags: u128) -> Self

Copy with flags set.

pub const fn without(self, flags: u128) -> Self

Copy with flags cleared.

pub const fn toggled(self, flags: u128) -> Self

Copy with flags toggled.

pub fn enable(&mut self, flags: u128)

Set flags in place.

pub fn disable(&mut self, flags: u128)

Clear flags in place.

pub fn toggle(&mut self, flags: u128)

Toggle flags in place.

Source

impl Flags<usize>

pub const fn empty() -> Self

Empty set.

pub const fn all() -> Self

All bits set.

pub const fn from_bits(b: usize) -> Self

Wrap raw bits.

pub const fn bits(self) -> usize

Underlying bits.

pub const fn has(self, flags: usize) -> bool

Every bit of flags is set in self. (has(0) is true.)

pub const fn has_all(self, flags: usize) -> bool

Alias for has. Reads better at call sites with multiple bits.

pub const fn has_any(self, flags: usize) -> bool

Any bit of flags is set in self.

pub const fn with(self, flags: usize) -> Self

Copy with flags set.

pub const fn without(self, flags: usize) -> Self

Copy with flags cleared.

pub const fn toggled(self, flags: usize) -> Self

Copy with flags toggled.

pub fn enable(&mut self, flags: usize)

Set flags in place.

pub fn disable(&mut self, flags: usize)

Clear flags in place.

pub fn toggle(&mut self, flags: usize)

Toggle flags in place.