#[repr(transparent)]pub struct Flags<T>(pub T);Expand description
Flag set wrapping a primitive unsigned integer.
For named, fixed sets of flags use the bitflags crate. Flags<T> is
for ad hoc flag manipulation where bit positions are data.
use bitkit::Flags;
const READ: u32 = 1 << 0;
const WRITE: u32 = 1 << 1;
let mut f = Flags::<u32>::empty();
f.enable(READ | WRITE);
assert!(f.has(READ));
assert!(f.has_all(READ | WRITE));Tuple Fields
0: TImplementations
Sourceimpl Flags<u8>
impl Flags<u8>
Sourceimpl Flags<u16>
impl Flags<u16>
Sourceimpl Flags<u32>
impl Flags<u32>
Sourceimpl Flags<u64>
impl Flags<u64>
Sourceimpl Flags<u128>
impl Flags<u128>